@@ -1,10 +1,17 @@
-from dataclasses import dataclass
-from typing import Optional
-from dapodik.base import DapodikObject
+from dataclasses import dataclass, field
+from typing import Any, List, Optional
+from dapodik import (DapodikObject, PesertaDidikBaru, Sekolah, Agama,
+                     KebutuhanKhusus, JenisTinggal, AlatTransportasi)
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('peserta_didik_id')
+@set_meta('peserta_didik_id',
+          sekolah=Sekolah,
+          pdb=PesertaDidikBaru,
+          agama=Agama,
+          kebutuhan_khusus=KebutuhanKhusus,
+          jenis_tinggal=JenisTinggal,
+          alat_transportasi=AlatTransportasi)
 @dataclass(eq=False)
 class PesertaDidik(DapodikObject):
     nama: str
@@ -89,9 +96,9 @@ class PesertaDidik(DapodikObject):
     nomor_telepon_rumah: str = ""
     nomor_telepon_seluler: str = ""
     email: str = ""
-    kebutuhan_khusus_id_selector = []
-    kebutuhan_khusus_id_selector_ayah = []
-    kebutuhan_khusus_id_selector_ibu = []
+    kebutuhan_khusus_id_selector: List[Any] = field(default_factory=list)
+    kebutuhan_khusus_id_selector_ayah: List[Any] = field(default_factory=list)
+    kebutuhan_khusus_id_selector_ibu: List[Any] = field(default_factory=list)
 
     @property
     def params(self):
