@@ -1,8 +1,8 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
-from dapodik.rest import (
+from dapodik import (
+    DapodikObject,
     Agama,
     Bank,
     JenisKeluar,
@@ -10,13 +10,30 @@ from dapodik.rest import (
     StatusKeaktifanPegawai,
     StatusKepegawaian,
     PangkatGolongan,
+    Sekolah,
     SumberGaji,
+    TahunAjaran,
+    JenisPtk,
+    LembagaPengangkat,
+    KeahlianLaboratorium,
 )
 from dapodik.utils.decorator import set_meta
-from .ptk_terdaftar import PtkTerdaftar
 
 
-@set_meta('ptk_id')
+@set_meta('ptk_id',
+          sekolah=Sekolah,
+          jenis_keluar=JenisKeluar,
+          tahun_ajaran=TahunAjaran,
+          status_kepegawaian=StatusKepegawaian,
+          jenis_ptk=JenisPtk,
+          agama=Agama,
+          status_keaktifan_pegawai=StatusKeaktifanPegawai,
+          lembaga_pengangkat=LembagaPengangkat,
+          pangkat_golongan=PangkatGolongan,
+          keahlian_laboratorium=KeahlianLaboratorium,
+          sumber_gaji=SumberGaji,
+          pengguna=Pengguna,
+          bank=Bank)
 @dataclass(eq=False)
 class Ptk(DapodikObject):
     ptk_terdaftar_id: str
@@ -80,7 +97,6 @@ class Ptk(DapodikObject):
     tmt_pengangkatan: str
     lembaga_pengangkat_id: str
     pangkat_golongan_id: str
-    keahlian_laboratorium_id: 99
     sumber_gaji_id: str
     nama_ibu_kandung: str
     status_perkawinan: str
@@ -111,77 +127,13 @@ class Ptk(DapodikObject):
     verifikasi_email: bool
     jenis_ptk_id_str: str
     vld_count: int
+    keahlian_laboratorium_id: Optional[int] = 99
 
     @property
-    @PtkTerdaftar.getter
-    def ptk_terdaftar(self) -> Optional[PtkTerdaftar]:
+    def ptk_terdaftar(self):
         return self.ptk_terdaftar_id
 
-    @property
-    @JenisKeluar.getter
-    def jenis_keluar(self) -> Optional[JenisKeluar]:
-        return self.jenis_keluar_id
-
-    @property
-    def tahun_ajaran(self):
-        pass
-
-    @property
-    def updater(self):
-        pass
-
-    @property
-    @StatusKepegawaian.getter
-    def status_kepegawaian(self) -> Optional[StatusKepegawaian]:
-        return self.status_kepegawaian_id
-
-    @property
-    def jenis_ptk(self):
-        pass
-
     @property
     def pengawas_bidang_studi(self):
-        pass
-
-    @property
-    @Agama.getter
-    def agama(self) -> Optional[Agama]:
-        return self.agama_id
-
-    @property
-    @StatusKeaktifanPegawai.getter
-    def status_keaktifan(self) -> Optional[StatusKeaktifanPegawai]:
-        return self.status_kepegawaian_id
-
-    @property
-    @PangkatGolongan.getter
-    def lembaga_pengangkat(self) -> Optional[PangkatGolongan]:
-        return self.lembaga_pengangkat_id
-
-    @property
-    @PangkatGolongan.getter
-    def pangkat_golongan(self) -> Optional[PangkatGolongan]:
-        return self.pangkat_golongan_id
-
-    @property
-    def keahlian_laboratorium(self):
-        pass
-
-    @property
-    @SumberGaji.getter
-    def sumber_gaji(self) -> Optional[SumberGaji]:
-        return self.sumber_gaji_id
-
-    @property
-    def blob(self):
-        pass
-
-    @property
-    @Pengguna.getter
-    def pengguna(self) -> Optional[Pengguna]:
-        return self.pengguna_id
-
-    @property
-    @Bank.getter
-    def bank(self) -> Optional[Bank]:
-        return self.id_bank
+        # TODO API
+        return self.pengawas_bidang_studi_id
