@@ -1,12 +1,12 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
 @set_meta('akses_internet_id')
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True)
 class AksesInternet(DapodikObject):
     akses_internet_id: int
     nama: str
