@@ -1,12 +1,12 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
 @set_meta('id_gmd')
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True)
 class Gmd(DapodikObject):
     id_gmd: str
     nm_gmd: str
