@@ -1,12 +1,12 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
 @set_meta('jenis_keluar_id')
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True)
 class JenisKeluar(DapodikObject):
     jenis_keluar_id: str
     ket_keluar: str
