@@ -1,11 +1,11 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, Sekolah, JenisSarana, Ptk
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_alat')
+@set_meta('id_alat', jenis_sarana=JenisSarana, sekolah=Sekolah, ptk=Ptk)
 @dataclass(eq=False)
 class Alat(DapodikObject):
     id_alat: str
@@ -38,3 +38,8 @@ class Alat(DapodikObject):
     vld_count: int
     key_match: str
     header: str
+
+    @property
+    def kepemilikan_sarpras(self):
+        # TODO API NF
+        return self.kepemilikan_sarpras_id
