@@ -1,10 +1,10 @@
 from dataclasses import dataclass
 from datetime import datetime
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, BlockGrant
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('bangunan_dari_blockgrant_id')
+@set_meta('bangunan_dari_blockgrant_id', blockgrant=BlockGrant)
 @dataclass(eq=False)
 class BangunanDariBlockgrant(DapodikObject):
     blockgrant_id: str
