@@ -1,10 +1,13 @@
 from dataclasses import dataclass
 from datetime import datetime
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, Sekolah, Akreditasi, LembagaPengangkat
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('akred_sp_id')
+@set_meta('akred_sp_id',
+          akred_sp=Akreditasi,
+          sekolah=Sekolah,
+          la=LembagaPengangkat)
 @dataclass(eq=False)
 class AkreditasiSp(DapodikObject):
     akred_sp_id: str
