@@ -1,10 +1,11 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
-from .yayasan import Yayasan
+from dapodik import DapodikObject, Yayasan, KebutuhanKhusus
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('sekolah_id', kebutuhan_khusus=KebutuhanKhusus, yayasan=Yayasan)
 @dataclass(eq=False)
 class Sekolah(DapodikObject):
     sekolah_id: str
@@ -31,7 +32,7 @@ class Sekolah(DapodikObject):
     sk_pendirian_sekolah: str
     tanggal_sk_pendirian: str
     status_kepemilikan_id: str
-    yayasan_id: Yayasan
+    yayasan_id: str
     sk_izin_operasional: str
     tanggal_sk_izin_operasional: str
     no_rekening: Optional[str]
@@ -58,10 +59,11 @@ class Sekolah(DapodikObject):
     vld_count: int
 
     @property
-    @Yayasan.getter
-    def yayasan(self):
-        return self.yayasan_id
+    def bentuk_pendidikan(self):
+        # TODO API
+        return self.bentuk_pendidikan_id
 
-    @yayasan.setter
-    def yayasan(self, value):
-        self.yayasan_id = value
+    @property
+    def status_kepemilikan(self):
+        # TODO API
+        return self.status_kepemilikan_id
